@@ -1,4 +1,6 @@
 from salesforce_tools.salesforce import SalesforceAPI, SalesforceModelFactory, SalesforceServicesData
 from salesforce_tools.auth import login, SalesforceOAuthClient
+from salesforce_tools.bulk import SalesforceBulkAPI, SalesforceBulkJobException
+from salesforce_tools.bulk_models import JobInfo, JobInfoList, JobTypeEnum, JobStateEnum
 from salesforce_tools.oauth_server import CallbackServer, OAuthCallbackHandler
 from salesforce_tools.util import SFDateTime, EmailValidator, EMAIL_ADDRESS_REGEX
\ No newline at end of file
